@@ -154,8 +154,8 @@
     sumry[1, ] <- c("$cw", length(x$cw), mode(x$cw), "column weights")
     sumry[2, ] <- c("$lw", length(x$lw), mode(x$lw), "row weights")
     sumry[3, ] <- c("$eig", length(x$eig), mode(x$eig), "eigen values")
-    class(sumry) <- "table"
-    print(sumry)
+    
+    print(sumry, quote = FALSE)
     cat("\n")
     sumry <- array("", c(5, 4), list(rep("", 5), c("data.frame", 
         "nrow", "ncol", "content")))
@@ -164,8 +164,8 @@
     sumry[3, ] <- c("$l1", nrow(x$l1), ncol(x$l1), "row normed scores")
     sumry[4, ] <- c("$co", nrow(x$co), ncol(x$co), "column coordinates")
     sumry[5, ] <- c("$c1", nrow(x$c1), ncol(x$c1), "column normed scores")
-    class(sumry) <- "table"
-    print(sumry)
+    
+    print(sumry, quote = FALSE)
     cat("\n     **** Intrastructure ****\n\n")
     sumry <- array("", c(4, 4), list(rep("", 4), c("data.frame", 
         "nrow", "ncol", "content")))
@@ -173,7 +173,7 @@
     sumry[2, ] <- c("$Tco", nrow(x$Tco), ncol(x$Tco), "col coordinates (each table)")
     sumry[3, ] <- c("$TL", nrow(x$TL), ncol(x$TL), "factors for Tli")
     sumry[4, ] <- c("$TC", nrow(x$TC), ncol(x$TC), "factors for Tco")
-    class(sumry) <- "table"
-    print(sumry)
+    
+    print(sumry, quote = FALSE)
     cat("\n")
 }
